@@ -38,12 +38,6 @@ romaji_typing_rule = {
     u"lu" : u"ぅ",
     u"le" : u"ぇ",
     u"lo" : u"ぉ",
-#    u"xka" : u"ゕ",
-    u"xka" : u"ヵ",
-#    u"xke" : u"ゖ",
-    u"xke" : u"ヶ",
-    u"wi" : u"うぃ",
-    u"we" : u"うぇ",
     u"wha" : u"うぁ",
     u"whi" : u"うぃ",
     u"whe" : u"うぇ",
@@ -58,6 +52,12 @@ romaji_typing_rule = {
     u"ku" : u"く",
     u"ke" : u"け",
     u"ko" : u"こ",
+    u"lka" : u"ヵ",
+    u"lke" : u"ヶ",
+#    u"xka" : u"ゕ",
+    u"xka" : u"ヵ",
+#    u"xke" : u"ゖ",
+    u"xke" : u"ヶ",
     u"ga" : u"が",
     u"gi" : u"ぎ",
     u"gu" : u"ぐ",
@@ -68,11 +68,13 @@ romaji_typing_rule = {
     u"kyu" : u"きゅ",
     u"kye" : u"きぇ",
     u"kyo" : u"きょ",
+    u"kwa" : u"くぁ",
     u"gya" : u"ぎゃ",
     u"gyi" : u"ぎぃ",
     u"gyu" : u"ぎゅ",
     u"gye" : u"ぎぇ",
     u"gyo" : u"ぎょ",
+    u"gwa" : u"ぐぁ",
     u"sa" : u"さ",
     u"si" : u"し",
     u"su" : u"す",
@@ -128,6 +130,11 @@ romaji_typing_rule = {
     u"tyu" : u"ちゅ",
     u"tye" : u"ちぇ",
     u"tyo" : u"ちょ",
+    u"cya" : u"ちゃ",
+    u"cyi" : u"ちぃ",
+    u"cyu" : u"ちゅ",
+    u"cye" : u"ちぇ",
+    u"cyo" : u"ちょ",
     u"cha" : u"ちゃ",
     u"chi" : u"ち",
     u"chu" : u"ちゅ",
@@ -139,6 +146,7 @@ romaji_typing_rule = {
     u"dye" : u"ぢぇ",
     u"dyo" : u"ぢょ",
     u"tsa" : u"つぁ",
+    u"tsi" : u"つぃ",
     u"tse" : u"つぇ",
     u"tso" : u"つぉ",
     u"tha" : u"てゃ",
@@ -146,11 +154,13 @@ romaji_typing_rule = {
     u"thu" : u"てゅ",
     u"the" : u"てぇ",
     u"tho" : u"てょ",
+    u"twu" : u"とぅ",
     u"dha" : u"でゃ",
     u"dhi" : u"でぃ",
     u"dhu" : u"でゅ",
     u"dhe" : u"でぇ",
     u"dho" : u"でょ",
+    u"dwu" : u"どぅ",
     u"na" : u"な",
     u"ni" : u"に",
     u"nu" : u"ぬ",
@@ -211,15 +221,21 @@ romaji_typing_rule = {
     u"myu" : u"みゅ",
     u"mye" : u"みぇ",
     u"myo" : u"みょ",
-    u"lya" : u"ゃ",
-    u"xya" : u"ゃ",
     u"ya" : u"や",
-    u"lyu" : u"ゅ",
-    u"xyu" : u"ゅ",
+    u"yi" : u"い",
     u"yu" : u"ゆ",
-    u"lyo" : u"ょ",
-    u"xyo" : u"ょ",
+    u"ye" : u"いぇ",
     u"yo" : u"よ",
+    u"lya" : u"ゃ",
+    u"lyi" : u"ぃ",
+    u"lyu" : u"ゅ",
+    u"lye" : u"ぇ",
+    u"lyo" : u"ょ",
+    u"xya" : u"ゃ",
+    u"xyi" : u"ぃ",
+    u"xyu" : u"ゅ",
+    u"xye" : u"ぇ",
+    u"xyo" : u"ょ",
     u"ra" : u"ら",
     u"ri" : u"り",
     u"ru" : u"る",
@@ -230,9 +246,13 @@ romaji_typing_rule = {
     u"ryu" : u"りゅ",
     u"rye" : u"りぇ",
     u"ryo" : u"りょ",
-    u"xwa" : u"ゎ",
     u"wa" : u"わ",
+    u"wi" : u"うぃ",
+    u"wu" : u"う",
+    u"we" : u"うぇ",
     u"wo" : u"を",
+    u"lwa" : u"ゎ",
+    u"xwa" : u"ゎ",
     u"n'" : u"ん",
     u"nn" : u"ん",
     u"wyi" : u"ゐ",
@@ -337,6 +357,11 @@ romaji_correction_rule = {
     u"n." : (u"ん", u"."),
 }
 
+# EUC-JP and SJIS do not have the chars
+romaji_utf8_rule = {
+    u"ヴ" : (u"ゔ"),
+}
+
 # a port of 101kana.sty from scim-anthy
 kana_typing_rule = {
     # no modifiers keys
